@@ -1,5 +1,22 @@
-/*
+/* rijndael - An implementation of the Rijndael cipher.
+ * Copyright (C) 2000 Rafael R. Sevilla <sevillar@team.ph.inter.net>
  *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
+/*
  * Rijndael is a 128/192/256-bit block cipher that accepts key sizes of
  * 128, 192, or 256 bits, designed by Joan Daemen and Vincent Rijmen.  See
  * http://www.esat.kuleuven.ac.be/~rijmen/rijndael/ for details.
@@ -20,8 +37,10 @@ typedef unsigned char UINT8;
 
 #define     MODE_ECB        1    /*  Are we ciphering in ECB mode?   */
 #define     MODE_CBC        2    /*  Are we ciphering in CBC mode?   */
-#define     MODE_CFB1       3    /*  Are we ciphering in 1-bit CFB mode? */
-
+#define     MODE_CFB        3    /*  Are we ciphering in 128-bit CFB mode? */
+#define     MODE_PCBC       4    /*  Are we ciphering in PCBC mode? */
+#define     MODE_OFB        5    /*  Are we ciphering in 128-bit OFB mode? */
+#define     MODE_CTR        6    /*  Are we ciphering in counter mode? */
 
 /* Allow keys of size 128 <= bits <= 256 */
 
@@ -80,4 +99,15 @@ rijndael_decrypt(RIJNDAEL_context *context,
 		 const UINT8 *ciphertext,
 		 UINT8 *plaintext);
 
+/* Encrypt a block of plaintext in a mode specified in the context */
+void
+block_encrypt(RIJNDAEL_context *ctx, UINT8 *input, int inputlen,
+	      UINT8 *output, UINT8 *iv);
+
+/* Decrypt a block of plaintext in a mode specified in the context */
+void
+block_decrypt(RIJNDAEL_context *ctx, UINT8 *input, int inputlen,
+	      UINT8 *output, UINT8 *iv);
+
+
 #endif /* RIJNDAEL_H */
